<?php
$TRANSLATIONS = array(
"Invalid value supplied for %s" => "Sisestatud sobimatu väärtus %s jaoks",
"Saved" => "Salvestatud",
"test email settings" => "testi e-posti seadeid",
"If you received this email, the settings seem to be correct." => "Kui said selle kirja, siis on seadistus korrektne.",
"A problem occurred while sending the e-mail. Please revisit your settings." => "Kirja saatmisel tekkis tõrge. Palun kontrolli üle oma seadistus.",
"Email sent" => "E-kiri on saadetud",
"You need to set your user email before being able to send test emails." => "Pead seadistama oma e-postienne kui on võimalik saata test-kirju.",
"Send mode" => "Saatmise viis",
"Encryption" => "Krüpteerimine",
"Authentication method" => "Autentimise meetod",
"Unable to load list from App Store" => "App Store'i nimekirja laadimine ebaõnnestus",
"Authentication error" => "Autentimise viga",
"Your full name has been changed." => "Sinu täispikk nimi on muudetud.",
"Unable to change full name" => "Täispika nime muutmine ebaõnnestus",
"Group already exists" => "Grupp on juba olemas",
"Unable to add group" => "Keela grupi lisamine",
"Files decrypted successfully" => "Failide krüpteerimine õnnestus",
"Couldn't decrypt your files, please check your owncloud.log or ask your administrator" => "Ei suutnud faile dekrüpteerida, palun kontrolli oma owncloud.log-i või küsi nõu administraatorilt",
"Couldn't decrypt your files, check your password and try again" => "Ei suutnud failde dekrüpteerida, kontrolli parooli ja proovi uuesti",
"Encryption keys deleted permanently" => "Krüpteerimisvõtmed kustutatud lõplikult",
"Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" => "Ei suutnud lõplikult kustutada sinu krüpteerimisvõtmeid, palun vaata owncloud.log-i või pöördu oma süsteemihalduri poole.",
"Couldn't remove app." => "Ei suutnud rakendit eemaldada.",
"Email saved" => "Kiri on salvestatud",
"Invalid email" => "Vigane e-post",
"Unable to delete group" => "Grupi kustutamine ebaõnnestus",
"Unable to delete user" => "Kasutaja kustutamine ebaõnnestus",
"Backups restored successfully" => "Varukoopiad taastatud edukalt.",
"Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" => "Ei suutnud taastada sinu krüpteerimisvõtmeid, palun vaata owncloud.log-i või  pöördu oma süsteemihalduri poole.",
"Language changed" => "Keel on muudetud",
"Invalid request" => "Vigane päring",
"Admins can't remove themself from the admin group" => "Administraatorid ei saa ise end admin grupist eemaldada",
"Unable to add user to group %s" => "Kasutajat ei saa lisada gruppi %s",
"Unable to remove user from group %s" => "Kasutajat ei saa eemaldada grupist %s",
"Couldn't update app." => "Rakenduse uuendamine ebaõnnestus.",
"Wrong password" => "Vale parool",
"No user supplied" => "Kasutajat ei sisestatud",
"Please provide an admin recovery password, otherwise all user data will be lost" => "Palun sisesta administraatori taasteparool, muidu kaotad kõik kasutajate andmed",
"Wrong admin recovery password. Please check the password and try again." => "Vale administraatori taasteparool. Palun kontrolli parooli ning proovi uuesti.",
"Back-end doesn't support password change, but the users encryption key was successfully updated." => "Tagarakend ei toeta parooli vahetust, kuid kasutaja krüptimisvõti uuendati edukalt.",
"Unable to change password" => "Ei suuda parooli muuta",
"Sending..." => "Saadan...",
"User Documentation" => "Kasutaja dokumentatsioon",
"Admin Documentation" => "Admin dokumentatsioon",
"Update to {appversion}" => "Uuenda versioonile {appversion}",
"Uninstall App" => "Eemada rakend",
"Disable" => "Lülita välja",
"Enable" => "Lülita sisse",
"Please wait...." => "Palun oota...",
"Error while disabling app" => "Viga rakenduse keelamisel",
"Error while enabling app" => "Viga rakenduse lubamisel",
"Updating...." => "Uuendamine...",
"Error while updating app" => "Viga rakenduse uuendamisel",
"Error" => "Viga",
"Update" => "Uuenda",
"Updated" => "Uuendatud",
"Uninstalling ...." => "Eemaldan...",
"Error while uninstalling app" => "Viga rakendi eemaldamisel",
"Uninstall" => "Eemalda",
"Select a profile picture" => "Vali profiili pilt",
"Very weak password" => "Väga nõrk parool",
"Weak password" => "Nõrk parool",
"So-so password" => "Enam-vähem sobiv parool",
"Good password" => "Hea parool",
"Strong password" => "Väga hea parool",
"Decrypting files... Please wait, this can take some time." => "Dekrüpteerin faile... Palun oota, see võib võtta veidi aega.",
"Delete encryption keys permanently." => "Kustuta krüpteerimisvõtmed lõplikult",
"Restore encryption keys." => "Taasta krüpteerimisvõtmed.",
"Unable to delete {objName}" => "Ei suuda kustutada {objName}",
"Error creating group" => "Viga grupi loomisel",
"A valid group name must be provided" => "Sisesta nõuetele vastav grupi nimi",
"deleted {groupName}" => "kustutatud {groupName}",
"undo" => "tagasi",
"Groups" => "Grupid",
"Group Admin" => "Grupi admin",
"Delete" => "Kustuta",
"never" => "mitte kunagi",
"deleted {userName}" => "kustutatud {userName}",
"add group" => "lisa grupp",
"A valid username must be provided" => "Sisesta nõuetele vastav kasutajatunnus",
"Error creating user" => "Viga kasutaja loomisel",
"A valid password must be provided" => "Sisesta nõuetele vastav parool",
"Warning: Home directory for user \"{user}\" already exists" => "Hoiatus: kasutaja \"{user}\" kodukataloog on juba olemas",
"__language_name__" => "Eesti",
"Everything (fatal issues, errors, warnings, info, debug)" => "Kõik (tõsised probleemid, veateated, hoiatused, info, veatuvastus)",
"Info, warnings, errors and fatal issues" => "Info, hoiatused, veateted ja tõsised probleemid",
"Warnings, errors and fatal issues" => "Hoiatused, veateated ja tõsised probleemid",
"Errors and fatal issues" => "Veateated ja tõsised probleemid",
"Fatal issues only" => "Ainult tõsised probleemid",
"None" => "Pole",
"Login" => "Logi sisse",
"Plain" => "Tavatekst",
"NT LAN Manager" => "NT LAN Manager",
"SSL" => "SSL",
"TLS" => "TLS",
"Security Warning" => "Turvahoiatus",
"You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." => "Sa kasutad %s ligipääsuks HTTP protokolli. Soovitame tungivalt seadistada oma server selle asemel kasutama HTTPS-i.",
"Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "Andmete kataloog ja failid on tõenäoliselt internetis avalikult saadaval. .htaccess fail, ei toimi. Soovitame tungivalt veebiserver seadistada selliselt, et andmete kataloog ei oleks enam vabalt saadaval või tõstaksid andmete kataloogi oma veebiserveri veebi juurkataloogist mujale.",
"Setup Warning" => "Paigalduse hoiatus",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "Veebiserveri ei ole veel korralikult seadistatud võimaldamaks failide sünkroniseerimist, kuna WebDAV liides näib olevat mittetoimiv.",
"Please double check the <a href=\"%s\">installation guides</a>." => "Palun kontrolli uuesti <a href=\"%s\">paigaldusjuhendeid</a>.",
"PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." => "PHP on seadistatud eemaldama \"inline\" dokumendi blokke. See muudab mõned rakendid kasutamatuteks.",
"This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." => "See on tõenäoliselt põhjustatud puhver/kiirendist nagu Zend OPcache või eAccelerator.",
"Database Performance Info" => "Andmebaasi toimimise info",
"SQLite is used as database. For larger installations we recommend to change this. To migrate to another database use the command line tool: 'occ db:convert-type'" => "Andmebaasina kasutatakse SQLite-t. Suuremate paigalduste puhul me soovitame seda muuta. Migreerimaks teisele andmebaasile kasuta seda käsurea vahendit: 'occ db:convert-type'",
"Module 'fileinfo' missing" => "Moodul 'fileinfo' puudub",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "PHP moodul 'fileinfo' puudub. Soovitame tungivalt see lisada saavutamaks parimaid tulemusi failitüüpide tuvastamisel.",
"Your PHP version is outdated" => "PHP versioon on aegunud",
"Your PHP version is outdated. We strongly recommend to update to 5.3.8 or newer because older versions are known to be broken. It is possible that this installation is not working correctly." => "Sinu PHP versioon on aegunud. Soovitame tungivalt uuenda versioonile 5.3.8 või uuemale, kuna varasemad versioonid on teadaolevalt vigased. On võimalik, et see käesolev paigaldus ei toimi korrektselt.",
"Locale not working" => "Lokalisatsioon ei toimi",
"System locale can not be set to a one which supports UTF-8." => "Süsteemi lokaliseeringuks ei saa panna sellist, mis toetab UTF-8-t.",
"This means that there might be problems with certain characters in file names." => "See tähendab, et võib esineda probleeme failide nimedes mõnede sümbolitega.",
"We strongly suggest to install the required packages on your system to support one of the following locales: %s." => "Soovitame tungivalt paigaldada vajalikud paketid oma süsteemi tagamaks tuge järgmistele lokaliseeringutele: %s.",
"Internet connection not working" => "Internetiühendus ei toimi",
"This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." => "Serveril puudub toimiv internetiühendus. See tähendab, et mõned funktsionaalsused, nagu näiteks väliste andmehoidlate ühendamine, teavitused uuendustest või kolmandate osapoolte rakenduste paigaldamine ei tööta. Eemalt failidele ligipääs ning teadete saatmine emailiga ei pruugi samuti toimida. Kui soovid täielikku funktsionaalsust, siis soovitame serverile tagada ligipääs internetti.",
"Cron" => "Cron",
"Last cron was executed at %s." => "Cron käivitati viimati %s.",
"Last cron was executed at %s. This is more than an hour ago, something seems wrong." => "Cron käivitati viimati %s. See on rohkem kui tund tagasi, midagi on valesti.",
"Cron was not executed yet!" => "Cron pole kordagi käivitatud!",
"Execute one task with each page loaded" => "Käivita toiming igal lehe laadimisel",
"cron.php is registered at a webcron service to call cron.php every 15 minutes over http." => "cron.php on registreeritud webcron teenuses, et käivitada fail cron.php iga 15 minuti tagant üle http.",
"Use system's cron service to call the cron.php file every 15 minutes." => "Kasuta süsteemi cron teenust, et käivitada fail cron.php iga 15 minuti tagant.",
"Sharing" => "Jagamine",
"Allow apps to use the Share API" => "Luba rakendustel kasutada Share API-t",
"Allow users to share via link" => "Luba kasutajatel lingiga jagamist ",
"Enforce password protection" => "Sunni parooliga kaitsmist",
"Allow public uploads" => "Luba avalikud üleslaadimised",
"Set default expiration date" => "Määra vaikimisi aegumise kuupäev",
"Expire after " => "Aegu pärast",
"days" => "päeva",
"Enforce expiration date" => "Sunnitud aegumise kuupäev",
"Allow resharing" => "Luba edasijagamine",
"Restrict users to only share with users in their groups" => "Luba kasutajatel jagada kasutajatega ainult oma grupi piires",
"Allow users to send mail notification for shared files" => "Luba kasutajatel saata e-posti teavitusi jagatud failide kohta",
"Exclude groups from sharing" => "Eemalda grupid jagamisest",
"These groups will still be able to receive shares, but not to initiate them." => "Need grupid saavad vastu võtta jagamisi, kuid ise jagamisi algatada ei saa.",
"Security" => "Turvalisus",
"Enforce HTTPS" => "Sunni peale HTTPS-i kasutamine",
"Forces the clients to connect to %s via an encrypted connection." => "Sunnib kliente %s ühenduma krüpteeritult.",
"Please connect to your %s via HTTPS to enable or disable the SSL enforcement." => "Palun ühendu oma %s üle HTTPS või keela SSL kasutamine.",
"Email Server" => "Postiserver",
"This is used for sending out notifications." => "Seda kasutatakse teadete välja saatmiseks.",
"From address" => "Saatja aadress",
"mail" => "e-mail",
"Authentication required" => "Autentimine on vajalik",
"Server address" => "Serveri aadress",
"Port" => "Port",
"Credentials" => "Kasutajatunnused",
"SMTP Username" => "SMTP kasutajatunnus",
"SMTP Password" => "SMTP parool",
"Test email settings" => "Testi e-posti seadeid",
"Send email" => "Saada kiri",
"Log" => "Logi",
"Log level" => "Logi tase",
"More" => "Rohkem",
"Less" => "Vähem",
"Version" => "Versioon",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Arendatud <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud kogukonna</a> poolt. <a href=\"https://github.com/owncloud\" target=\"_blank\">Lähtekood</a> on avaldatud ja kaetud <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a> litsentsiga.",
"Add your App" => "Lisa oma rakendus",
"More Apps" => "Veel rakendusi",
"Select an App" => "Vali programm",
"Documentation:" => "Dokumentatsioon:",
"See application page at apps.owncloud.com" => "Vaata rakenduste lehte aadressil apps.owncloud.com",
"See application website" => "Vaata rakendi veebilehte",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-litsenseeritud <span class=\"author\"></span>",
"Enable only for specific groups" => "Luba ainult kindlad grupid",
"All" => "Kõik",
"Administrator Documentation" => "Administraatori dokumentatsioon",
"Online Documentation" => "Online dokumentatsioon",
"Forum" => "Foorum",
"Bugtracker" => "Vigade nimekiri",
"Commercial Support" => "Tasuline kasutajatugi",
"Get the apps to sync your files" => "Hangi rakendusi failide sünkroniseerimiseks",
"Show First Run Wizard again" => "Näita veelkord Esmase Käivituse Juhendajat",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Kasutad <strong>%s</strong> saadavalolevast <strong>%s</strong>",
"Password" => "Parool",
"Your password was changed" => "Sinu parooli on muudetud",
"Unable to change your password" => "Sa ei saa oma parooli muuta",
"Current password" => "Praegune parool",
"New password" => "Uus parool",
"Change password" => "Muuda parooli",
"Full Name" => "Täispikk nimi",
"Email" => "E-post",
"Your email address" => "Sinu e-posti aadress",
"Fill in an email address to enable password recovery and receive notifications" => "Täida e-posti aadress võimaldamaks parooli taastamist ning teadete saamist.",
"Profile picture" => "Profiili pilt",
"Upload new" => "Laadi uus üles",
"Select new from Files" => "Vali failidest uus",
"Remove image" => "Eemalda pilt",
"Either png or jpg. Ideally square but you will be able to crop it." => "Kas png või jpg. Võimalikult ruudukujuline, kuid sul on võimalus seda veel lõigata.",
"Your avatar is provided by your original account." => "Sinu avatari pakub sinu algne konto.",
"Cancel" => "Loobu",
"Choose as profile image" => "Vali profiilipildiks",
"Language" => "Keel",
"Help translate" => "Aita tõlkida",
"The encryption app is no longer enabled, please decrypt all your files" => "Küpteeringu rakend pole lubatud, dekrüpteeri kõik oma failid",
"Log-in password" => "Sisselogimise parool",
"Decrypt all Files" => "Dekrüpteeri kõik failid",
"Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly." => "Sinu krüpteerimisvõtmed on tõstetud varukoopiasse. Kui midagi läheb valesti, siis saad võtmed taastada. Kustuta lõplikult ainult juhul kui oled kindel, et failid on dekrüteeritud korrektselt.",
"Restore Encryption Keys" => "Taasta krüpteerimisvõtmed",
"Delete Encryption Keys" => "Kustuta krüpteerimisvõtmed",
"Login Name" => "Kasutajanimi",
"Create" => "Lisa",
"Admin Recovery Password" => "Admini parooli taastamine",
"Enter the recovery password in order to recover the users files during password change" => "Sisesta taasteparool kasutaja failide taastamiseks paroolivahetuse käigus",
"Search Users and Groups" => "Otsi kasutajaid ja gruppe",
"Add Group" => "Lisa grupp",
"Group" => "Grupp",
"Everyone" => "Igaüks",
"Admins" => "Haldurid",
"Default Quota" => "Vaikimisi kvoot",
"Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" => "Palun sisesta mahupiir (nt: \"512 MB\" või \"12 GB\")",
"Unlimited" => "Piiramatult",
"Other" => "Muu",
"Username" => "Kasutajanimi",
"Quota" => "Mahupiir",
"Storage Location" => "Mahu asukoht",
"Last Login" => "Viimane sisselogimine",
"change full name" => "Muuda täispikka nime",
"set new password" => "määra uus parool",
"Default" => "Vaikeväärtus",
"If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwritewebroot\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" => "Kui sinu sait pole paigaldatud domeeni juurkausta ja see kasutab ajastatud tegevusi, siis võib tekkide probleeme URL-ide loomisega. Nende probleemide vältimiseks sisesta palun failis config.php valikusse \"overwritewebroot\" oma veebiserveri juurkaust (Soovituslik: \"%s\")",
"URL generation in notification emails" => "URL-ide loomine teavituskirjades",
"Connectivity Checks" => "Ühenduse kontrollid",
"No problems found" => "Ühtegi probleemi ei leitud",
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
